@@ -1,9 +1,12 @@
 # Copyright (c) OpenMMLab. All rights reserved.
 from .inference import init_detector, model_inference
+from .test import single_gpu_test
 from .train import init_random_seed, train_detector
-from .utils import disable_text_recog_aug_test, replace_image_to_tensor
+from .utils import (disable_text_recog_aug_test, replace_image_to_tensor,
+                    tensor2grayimgs)
 
 __all__ = [
     'model_inference', 'train_detector', 'init_detector', 'init_random_seed',
-    'replace_image_to_tensor', 'disable_text_recog_aug_test'
+    'replace_image_to_tensor', 'disable_text_recog_aug_test',
+    'single_gpu_test', 'tensor2grayimgs'
 ]
