@@ -178,8 +178,8 @@ class BaseRecognizer(BaseModule, metaclass=ABCMeta):
 
         return outputs
 
-    def show_result(self,
-                    img,
+    @staticmethod
+    def show_result(img,
                     result,
                     gt_label='',
                     win_name='',
