@@ -1,8 +1,8 @@
 # Copyright (c) OpenMMLab. All rights reserved.
-from mmocr.models.builder import DETECTORS
+from mmocr.models.builder import RECOGNIZERS
 from .encode_decode_recognizer import EncodeDecodeRecognizer
 
 
-@DETECTORS.register_module()
+@RECOGNIZERS.register_module()
 class SARNet(EncodeDecodeRecognizer):
     """Implementation of `SAR <https://arxiv.org/abs/1811.00751>`_"""
