@@ -1,7 +1,8 @@
-from mmocr.models.builder import DETECTORS
+# Copyright (c) OpenMMLab. All rights reserved.
+from mmocr.models.builder import RECOGNIZERS
 from .encode_decode_recognizer import EncodeDecodeRecognizer
 
 
-@DETECTORS.register_module()
+@RECOGNIZERS.register_module()
 class SATRN(EncodeDecodeRecognizer):
     """Implementation of `SATRN <https://arxiv.org/abs/1910.04396>`_"""
