@@ -9,7 +9,11 @@ import lmdb
 from mmocr.utils import list_from_file
 
 
-def lmdb_converter(img_list_file, output, batch_size=1000, coding='utf-8'):
+def lmdb_converter(img_list_file,
+                   output,
+                   batch_size=1000,
+                   coding='utf-8',
+                   lmdb_map_size=109951162776):
     # read img_list_file
     lines = list_from_file(img_list_file)
 
@@ -25,7 +29,7 @@ def lmdb_converter(img_list_file, output, batch_size=1000, coding='utf-8'):
                 return
     print('create database %s' % output)
     Path(output).mkdir(parents=True, exist_ok=False)
-    env = lmdb.open(output, map_size=1099511627776)
+    env = lmdb.open(output, map_size=lmdb_map_size)
 
     # build lmdb
     beg_time = time.strftime('%H:%M:%S')
